Index: src/compiler/common-operator.h |
diff --git a/src/compiler/common-operator.h b/src/compiler/common-operator.h |
index b823e0fa154df51dd0346d71d18a98e882c7ab87..d54bcc531109bba685b47ceaef3772c94c7647ce 100644 |
--- a/src/compiler/common-operator.h |
+++ b/src/compiler/common-operator.h |
@@ -297,9 +297,9 @@ SparseInputMask SparseInputMaskOf(Operator const*); |
ZoneVector<MachineType> const* MachineTypesOf(Operator const*) |
WARN_UNUSED_RESULT; |
// The ArgumentsElementsState can either describe an unmapped arguments backing |
// store or the backing store of the rest parameters. IsRestOf(op) is true in |
// the second case. |
bool IsRestOf(Operator const*); |
// Interface for building common operators that can be used at any level of IR, |
@@ -368,6 +368,7 @@ class V8_EXPORT_PRIVATE CommonOperatorBuilder final |
const Operator* TypedStateValues(const ZoneVector<MachineType>* types, |
SparseInputMask bitmask); |
const Operator* ArgumentsElementsState(bool is_rest); |
+ const Operator* ArgumentsLengthState(bool is_rest); |
const Operator* ObjectState(int pointer_slots); |
const Operator* TypedObjectState(const ZoneVector<MachineType>* types); |
const Operator* FrameState(BailoutId bailout_id, |
@@ -297,9 +297,9 @@ SparseInputMask SparseInputMaskOf(Operator const*); |
ZoneVector<MachineType> const* MachineTypesOf(Operator const*) |
WARN_UNUSED_RESULT; |
-// The ArgumentsElementsState can either describe an unmapped arguments backing |
-// store or the backing store of the rest parameters. IsRestOf(op) is true in |
-// the second case. |
+// The ArgumentsElementsState and ArgumentsLengthState can either describe an |
+// unmapped arguments backing store or the backing store of the rest parameters. |
+// IsRestOf(op) is true in the second case. |
bool IsRestOf(Operator const*); |
// Interface for building common operators that can be used at any level of IR, |